@@ -11,6 +11,8 @@ from tracwikiimporter.importer import (
 
 
 class TestTracWikiImporter(TestCase):
+
+    @patch('tracwikiimporter.importer.AuditLog')
     @patch('tracwikiimporter.importer.session')
     @patch('tracwikiimporter.importer.tempfile.NamedTemporaryFile')
     @patch('tracwikiimporter.importer.g')
@@ -21,7 +23,7 @@ class TestTracWikiImporter(TestCase):
     @patch('tracwikiimporter.importer.ApiTicket')
     @patch('tracwikiimporter.importer.datetime')
     def test_import_tool(self, dt, ApiTicket, WikiExporter, Namespace,
-            load_data, WikiFromTrac, g, NamedTemporaryFile, session):
+            load_data, WikiFromTrac, g, NamedTemporaryFile, session, AuditLog):
         from datetime import datetime, timedelta
         now = datetime.utcnow()
         dt.utcnow.return_value = now
@@ -30,6 +32,8 @@ class TestTracWikiImporter(TestCase):
 
         importer = TracWikiImporter()
         app = Mock(name='ForgeWikiApp')
+        app.config.options.mount_point = 'pages'
+        app.url = 'foo'
         project = Mock(name='Project', shortname='myproject')
         project.install_app.return_value = app
         user = Mock(name='User', _id='id')
@@ -39,7 +43,12 @@ class TestTracWikiImporter(TestCase):
                 trac_url='http://example.com/trac/url')
         self.assertEqual(res, app)
         project.install_app.assert_called_once_with(
-                'Wiki', mount_point='pages', mount_label='Pages')
+                'Wiki', mount_point='pages', mount_label='Pages',
+                import_id={
+                        'source': 'Trac',
+                        'trac_url': 'http://example.com/trac/url/',
+                    },
+            )
         ApiTicket.assert_called_once_with(
                 user_id=user._id,
                 capabilities={"import": ["Projects", "myproject"]},
@@ -49,6 +58,12 @@ class TestTracWikiImporter(TestCase):
         WikiExporter.return_value.export.assert_called_once_with(export_file)
         load_data.assert_called_once_with('/my/file',
                 WikiFromTrac.parser.return_value, Namespace.return_value)
+        AuditLog.log.assert_called_once_with(
+                'import tool pages from http://example.com/trac/url/',
+                project=project,
+                user=user,
+                url='foo',
+            )
         g.post_event.assert_called_once_with('project_updated')
 
     @patch('tracwikiimporter.importer.session')
